================================
Nanostructure Generator classes
================================

.. sectionauthor:: Andrew Merrill <androomerrill@gmail.com>

The :py:mod:`~sknano.nanogen` module provides the following
classes for generating nanostructures:

Graphene Structure Generators
=============================
* :py:class:`~sknano.nanogen.GrapheneGenerator`
* :py:class:`~sknano.nanogen.BiLayerGrapheneGenerator`

Nanotube Structure Generators
=============================

* :py:class:`~sknano.nanogen.NanotubeGenerator`
* :py:class:`~sknano.nanogen.NanotubeBundleGenerator`
* :py:class:`~sknano.nanogen.MWNTGenerator`
* :py:class:`~sknano.nanogen.MWNTBundleGenerator`
* :py:class:`~sknano.nanogen.TubeGen`
